/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg;

import java.io.File;
import java.util.List;

public class Bundle {

    private final BaseRepository baseRepository;

    private OverlayRepository overlayRepository;

    private final File file;

    private List<Changeset> changesets;

    public Bundle(BaseRepository baseRepository, File file) {
        this.baseRepository = baseRepository;
        this.overlayRepository = new OverlayRepository(baseRepository, this);
        this.file = file;
    }

    /**
     * 
     * @return the underlying file for the bundle
     */
    public File getFile() {
        return file;
    }

    public void init(List<Changeset> changesets) {
        this.changesets = changesets;
    }

    public List<Changeset> getChangesets() {
        return changesets;
    }

    public void close() {
        Repository repo = this.overlayRepository;
        repo.close();
        getFile().delete();
        this.overlayRepository = null;
    }

    public BaseRepository getBaseRepository() {
        return baseRepository;
    }

    public OverlayRepository getOverlayRepository() {
        return overlayRepository;
    }

}
