/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg.commands;

import java.io.IOException;

import com.aragost.javahg.Repository;
import com.aragost.javahg.commands.flags.MergeCommandFlags;
import com.aragost.javahg.internals.UpdateMergeHelper;

/**
 * Command class for executing <tt>hg merge</tt>. Set flags from
 * {@link MergeCommandFlags} and call the {@link #execute} method.
 */
public class MergeCommand extends MergeCommandFlags {

    /**
     * @param repository
     *            the repository associated with this command.
     */
    public MergeCommand(Repository repository) {
        super(repository);
    }

    /**
     * Perform the merge. Since a merge is an interactive command, a
     * "merge oracle" must be supplied to answer any questions from
     * Mercurial.
     * <p>
     * Feedback about this API will be greatly appreciated.
     * 
     * @param oracle
     * @return if no conflicts return true otherwise false
     * @throws IOException
     */
    public boolean execute(ManifestMergeOracle oracle) throws IOException {
        new UpdateMergeHelper(launchStream(), oracle, this).merge();
        return getReturnCode() == 0;
    }

    @Override
    public boolean isSuccessful() {
        return super.isSuccessful() || getReturnCode() == 1;
    }
}
